========================================
FIAT: FInite element Automatic Tabulator
========================================

The FInite element Automatic Tabulator FIAT supports generation of
arbitrary order instances of the Lagrange elements on lines,
triangles, and tetrahedra. It is also capable of generating arbitrary
order instances of Jacobi-type quadrature rules on the same element
shapes. Further, H(div) and H(curl) conforming finite element spaces
such as the families of Raviart-Thomas, Brezzi-Douglas-Marini and
Nedelec are supported on triangles and tetrahedra. Upcoming versions
will also support Hermite and nonconforming elements.

FIAT is part of the FEniCS Project.

For more information, visit http://www.fenicsproject.org


Documentation
=============

Documentation can be viewed at http://fenics-fiat.readthedocs.org/.

.. image:: https://readthedocs.org/projects/fenics-fiat/badge/?version=latest
   :target: http://fenics.readthedocs.io/projects/fiat/en/latest/?badge=latest
   :alt: Documentation Status


Automated Testing
-----------------

We use Bitbucket Pipelines and Atlassian Bamboo to perform automated
testing.

.. image:: https://bitbucket-badges.useast.atlassian.io/badge/fenics-project/fiat.svg
   :target: https://bitbucket.org/fenics-project/fiat/addon/pipelines/home
   :alt: Pipelines Build Status

.. image:: http://magpie.bpi.cam.ac.uk:8085/plugins/servlet/wittified/build-status/FIAT-FD
   :target: http://magpie.bpi.cam.ac.uk:8085/browse/FIAT-FD
   :alt: Bamboo Build Status


Code Coverage
-------------

Code coverage reports can be viewed at
https://coveralls.io/bitbucket/fenics-project/fiat.

.. image:: https://coveralls.io/repos/bitbucket/fenics-project/fiat/badge.svg?branch=master
   :target: https://coveralls.io/bitbucket/fenics-project/fiat?branch=master
   :alt: Coverage Status


License
=======

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU Lesser General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public License
  along with this program. If not, see <http://www.gnu.org/licenses/>.
